@@ -331,6 +331,61 @@ def test_render_with_style():
     assert params == [5]
 
 
+def test_tsql_render_with_select_query_builder():
+    """Test that tsql.render() works with SelectQueryBuilder"""
+    query = Users.select(Users.id, Users.username).where(Users.id > 5)
+
+    sql, params = tsql.render(query)
+
+    assert 'SELECT users.id, users.username' in sql
+    assert 'WHERE users.id > ?' in sql
+    assert params == [5]
+
+
+def test_tsql_render_with_insert_builder():
+    """Test that tsql.render() works with InsertBuilder"""
+    query = Users.insert(username='bob', email='bob@example.com')
+
+    sql, params = tsql.render(query)
+
+    assert 'INSERT INTO users' in sql
+    assert 'username' in sql and 'email' in sql
+    assert params == ['bob', 'bob@example.com']
+
+
+def test_tsql_render_with_update_builder():
+    """Test that tsql.render() works with UpdateBuilder"""
+    query = Users.update(username='updated').where(Users.id == 5)
+
+    sql, params = tsql.render(query)
+
+    assert 'UPDATE users SET' in sql
+    assert 'username = ?' in sql
+    assert 'WHERE users.id = ?' in sql
+    assert params == ['updated', 5]
+
+
+def test_tsql_render_with_delete_builder():
+    """Test that tsql.render() works with DeleteBuilder"""
+    query = Users.delete().where(Users.id == 5)
+
+    sql, params = tsql.render(query)
+
+    assert 'DELETE FROM users' in sql
+    assert 'WHERE users.id = ?' in sql
+    assert params == [5]
+
+
+def test_tsql_render_with_query_builder_and_style():
+    """Test that tsql.render() works with query builder and custom style"""
+    query = Users.select().where(Users.id == 5)
+
+    sql, params = tsql.render(query, style=tsql.styles.NUMERIC_DOLLAR)
+
+    assert '$1' in sql
+    assert params == [5]
+
+
 def test_schema_support():
     """Test that schema parameter works"""
     class SchemaUsers(Table, table_name='users', schema='public'):
@@ -838,23 +893,81 @@ def test_tstring_with_params_in_select():
     assert params == [' - ', 5]
 
 
-def test_column_is_null_property():
-    """Test is_null property"""
-    condition = Users.email.is_null
+def test_select_table_all():
+    """Test selecting all columns from a table using Table.ALL"""
+    query = Posts.select(Posts.ALL)
+    sql, params = query.render()
+
+    assert 'SELECT posts.*' in sql
+    assert 'FROM posts' in sql
+    assert params == []
+
+
+def test_select_table_all_with_other_columns():
+    """Test mixing Table.ALL with specific columns from another table"""
+    query = Posts.select(Posts.ALL, Users.username, Users.email)
+    sql, params = query.render()
+
+    assert 'SELECT posts.*, users.username, users.email' in sql
+    assert 'FROM posts' in sql
+    assert params == []
+
+
+def test_select_multiple_table_alls():
+    """Test selecting all columns from multiple tables"""
+    query = Posts.select(Posts.ALL, Users.ALL)
+    sql, params = query.render()
+
+    assert 'SELECT posts.*, users.*' in sql
+    assert 'FROM posts' in sql
+    assert params == []
+
+
+def test_select_table_all_with_join():
+    """Test Table.ALL in a real-world join scenario"""
+    query = (Posts.select(Posts.ALL, Users.username)
+             .join(Users, Posts.user_id == Users.id)
+             .where(Posts.id > 100))
+    sql, params = query.render()
+
+    assert 'SELECT posts.*, users.username' in sql
+    assert 'FROM posts' in sql
+    assert 'INNER JOIN users ON posts.user_id = users.id' in sql
+    assert 'WHERE posts.id > ?' in sql
+    assert params == [100]
+
+
+def test_select_table_all_with_schema():
+    """Test that Table.ALL works with schema-qualified tables"""
+    class Accounts(Table, table_name='accounts', schema='other'):
+        id: Column
+        name: Column
+
+    query = Accounts.select(Accounts.ALL)
+    sql, params = query.render()
+
+    assert 'SELECT other.accounts.*' in sql
+    assert 'FROM other.accounts' in sql
+    assert params == []
+
+
+def test_column_is_null_method():
+    """Test is_null method"""
+    condition = Users.email.is_null()
     assert condition.operator == 'IS'
     assert condition.right is None
 
 
-def test_column_is_not_null_property():
-    """Test is_not_null property"""
-    condition = Users.email.is_not_null
+def test_column_is_not_null_method():
+    """Test is_not_null method"""
+    condition = Users.email.is_not_null()
     assert condition.operator == 'IS NOT'
     assert condition.right is None
 
 
 def test_where_with_is_null():
     """Test WHERE with is_null"""
-    query = Users.select().where(Users.email.is_null)
+    query = Users.select().where(Users.email.is_null())
     sql, params = query.render()
 
     assert 'WHERE users.email IS NULL' in sql
@@ -863,7 +976,7 @@ def test_where_with_is_null():
 
 def test_where_with_is_not_null():
     """Test WHERE with is_not_null"""
-    query = Users.select().where(Users.email.is_not_null)
+    query = Users.select().where(Users.email.is_not_null())
     sql, params = query.render()
 
     assert 'WHERE users.email IS NOT NULL' in sql
@@ -1002,7 +1115,7 @@ def test_complex_query_with_new_operators():
     """Test complex query using multiple new operators"""
     query = (Users.select()
              .where(Users.id.between(1, 100))
-             .where(Users.email.is_not_null)
+             .where(Users.email.is_not_null())
              .where(Users.id.not_in([5, 10, 15]))
              .where(Users.username.ilike('%test%')))
     sql, params = query.render()
