@@ -258,8 +258,8 @@ def render(query: TSQLQuery, style=None) -> RenderedQuery:
         TypeError: If query is a raw string (use t-strings instead)
     """
     # Handle QueryBuilder (duck typing to avoid circular import)
-    if hasattr(query, 'build') and callable(query.build):
-        query = query.build()
+    if hasattr(query, 'to_tsql') and callable(query.to_tsql):
+        query = query.to_tsql()
 
     if isinstance(query, str):
         raise TypeError(
@@ -361,6 +361,7 @@ def delete(table: str, id: str | int) -> TSQL:
 
 
 from tsql.query_builder import UnsafeQueryError
+from tsql.type_processor import TypeProcessor
 
 __all__ = [
     'TSQL',
@@ -373,5 +374,6 @@ __all__ = [
     'delete',
     'set_style',
     'UnsafeQueryError',
+    'TypeProcessor',
 ]
 
