@@ -38,12 +38,12 @@ class OrderByClause:
 class Column:
     """Represents a bound column (table + column name) for building queries"""
 
-    def __init__(self, table_name: str = None, column_name: str = None, python_type: type = None, alias: str = None, schema: str = None):
+    def __init__(self, table_name: str | None = None, column_name: str | None = None, alias: str | None = None, schema: str | None = None, type_processor: Any | None = None):
         self.table_name = table_name
         self.column_name = column_name
-        self.python_type = python_type
         self.alias = alias
         self.schema = schema
+        self.type_processor = type_processor
 
     def __str__(self) -> str:
         if self.schema:
@@ -71,29 +71,48 @@ class Column:
         Example:
             users.select(users.first_name.as_('first'), users.last_name.as_('last'))
         """
-        return Column(self.table_name, self.column_name, self.python_type, alias, self.schema)
+        return Column(self.table_name, self.column_name, alias, self.schema, self.type_processor)
+
+    def _process_value(self, value: Any) -> Any:
+        """Apply type processor to a comparison value if one is configured.
+
+        Args:
+            value: The value to process
+
+        Returns:
+            The processed value (or unchanged if no processor or value is special type)
+        """
+        # Don't process special types
+        if value is None or isinstance(value, (Column, Template)) or hasattr(value, 'to_tsql'):
+            return value
+
+        # Apply processor if present
+        if self.type_processor is not None:
+            return self.type_processor.process_bind_param(value)
+
+        return value
 
     def __eq__(self, other) -> 'Condition':
         if other is None:
             return Condition(self, 'IS', None)
-        return Condition(self, '=', other)
+        return Condition(self, '=', self._process_value(other))
 
     def __ne__(self, other) -> 'Condition':
         if other is None:
             return Condition(self, 'IS NOT', None)
-        return Condition(self, '!=', other)
+        return Condition(self, '!=', self._process_value(other))
 
     def __lt__(self, other) -> 'Condition':
-        return Condition(self, '<', other)
+        return Condition(self, '<', self._process_value(other))
 
     def __le__(self, other) -> 'Condition':
-        return Condition(self, '<=', other)
+        return Condition(self, '<=', self._process_value(other))
 
     def __gt__(self, other) -> 'Condition':
-        return Condition(self, '>', other)
+        return Condition(self, '>', self._process_value(other))
 
     def __ge__(self, other) -> 'Condition':
-        return Condition(self, '>=', other)
+        return Condition(self, '>=', self._process_value(other))
 
     def in_(self, values: Union[list, tuple, 'Column', Template, 'SelectQueryBuilder']) -> 'Condition':
         """Create an IN condition
@@ -102,7 +121,9 @@ class Column:
             values: List/tuple of values, a Column, a Template (t-string), or a SelectQueryBuilder for subqueries
         """
         if isinstance(values, (list, tuple)):
-            return Condition(self, 'IN', tuple(values))
+            # Process each value in the tuple/list
+            processed_values = tuple(self._process_value(v) for v in values)
+            return Condition(self, 'IN', processed_values)
         return Condition(self, 'IN', values)
 
     def not_in(self, values: Union[list, tuple, 'Column', Template, 'SelectQueryBuilder']) -> 'Condition':
@@ -112,24 +133,26 @@ class Column:
             values: List/tuple of values, a Column, a Template (t-string), or a SelectQueryBuilder for subqueries
         """
         if isinstance(values, (list, tuple)):
-            return Condition(self, 'NOT IN', tuple(values))
+            # Process each value in the tuple/list
+            processed_values = tuple(self._process_value(v) for v in values)
+            return Condition(self, 'NOT IN', processed_values)
         return Condition(self, 'NOT IN', values)
 
     def like(self, pattern: str) -> 'Condition':
         """Create a LIKE condition"""
-        return Condition(self, 'LIKE', pattern)
+        return Condition(self, 'LIKE', self._process_value(pattern))
 
     def not_like(self, pattern: str) -> 'Condition':
         """Create a NOT LIKE condition"""
-        return Condition(self, 'NOT LIKE', pattern)
+        return Condition(self, 'NOT LIKE', self._process_value(pattern))
 
     def ilike(self, pattern: str) -> 'Condition':
         """Create an ILIKE condition (case-insensitive, PostgreSQL/SQLite only)"""
-        return Condition(self, 'ILIKE', pattern)
+        return Condition(self, 'ILIKE', self._process_value(pattern))
 
     def not_ilike(self, pattern: str) -> 'Condition':
         """Create a NOT ILIKE condition (case-insensitive, PostgreSQL/SQLite only)"""
-        return Condition(self, 'NOT ILIKE', pattern)
+        return Condition(self, 'NOT ILIKE', self._process_value(pattern))
 
     def between(self, start: Any, end: Any) -> 'Condition':
         """Create a BETWEEN condition
@@ -138,7 +161,7 @@ class Column:
             start: Lower bound value
             end: Upper bound value
         """
-        return Condition(self, 'BETWEEN', (start, end))
+        return Condition(self, 'BETWEEN', (self._process_value(start), self._process_value(end)))
 
     def not_between(self, start: Any, end: Any) -> 'Condition':
         """Create a NOT BETWEEN condition
@@ -147,14 +170,12 @@ class Column:
             start: Lower bound value
             end: Upper bound value
         """
-        return Condition(self, 'NOT BETWEEN', (start, end))
+        return Condition(self, 'NOT BETWEEN', (self._process_value(start), self._process_value(end)))
 
-    @property
     def is_null(self) -> 'Condition':
         """Create an IS NULL condition"""
         return Condition(self, 'IS', None)
 
-    @property
     def is_not_null(self) -> 'Condition':
         """Create an IS NOT NULL condition"""
         return Condition(self, 'IS NOT', None)
@@ -197,18 +218,46 @@ class Table:
         class Users(Table, table_name='user_accounts'):
             id: Column
 
-    For SQLAlchemy integration, use SQLAlchemy Column objects:
+    For SQLAlchemy integration, use the SAColumn wrapper for type checker compatibility:
 
-        from sqlalchemy import Column, Integer, String
+        from sqlalchemy import Integer, String
+        from tsql.query_builder import Table, SAColumn
 
         class Users(Table, metadata=metadata, schema='public'):
-            id = Column(Integer, primary_key=True)
-            name = Column(String(100))
+            id = SAColumn(Integer, primary_key=True)
+            name = SAColumn(String(100))
+
+    Alternative: Use explicit type annotations with SQLAlchemy Column:
+
+        from sqlalchemy import Column as SACol
+
+        class Users(Table, metadata=metadata):
+            id: Column = SACol(Integer, primary_key=True)
+            name: Column = SACol(String(100))
+
+    Table-level constraints (for SQLAlchemy/Alembic migrations):
+
+        from sqlalchemy import UniqueConstraint, CheckConstraint
+
+        class Users(Table, metadata=metadata):
+            id = SAColumn(String, primary_key=True)
+            tenant_id = SAColumn(String)
+            email = SAColumn(String)
+
+            constraints = [
+                UniqueConstraint('tenant_id', 'email', name='uq_users_tenant_email'),
+                CheckConstraint('length(email) > 0', name='ck_users_email_not_empty')
+            ]
+
+    Table comment (for database documentation in migrations):
+
+        class Users(Table, metadata=metadata, comment='Application user accounts'):
+            id = SAColumn(Integer, primary_key=True)
     """
     table_name: ClassVar[str]
     schema: ClassVar[Optional[str]] = None
 
-    def __init_subclass__(cls, table_name: Optional[str] = None, metadata: Optional[Any] = None, schema: Optional[str] = None, **kwargs):
+    def __init_subclass__(cls, table_name: Optional[str] = None, metadata: Optional[Any] = None, schema: Optional[str] = None, comment: Optional[str] = None, **kwargs):
         super().__init_subclass__(**kwargs)
 
         # Set table_name: use provided name, or default to lowercase class name
@@ -217,6 +266,7 @@ class Table:
 
         annotations = getattr(cls, '__annotations__', {})
         sa_columns = []
+        cls._type_processors = {}
 
         # Collect all potential column fields
         all_fields = {}
@@ -234,7 +284,7 @@ class Table:
                 continue
             field_value = getattr(cls, field_name, None)
 
-            # Check for Ellipsis syntax: id = ...
+            # Check for Ellipsis syntax: id = ...~
             if field_value is ...:
                 if field_name not in all_fields:
                     all_fields[field_name] = {
@@ -270,8 +320,19 @@ class Table:
                     sa_col.name = field_name
                     sa_columns.append(sa_col)
 
-                # Create query builder ColumnDescriptor
-                setattr(cls, field_name, ColumnDescriptor(field_name, field_type))
+                # Extract type processor if present
+                type_processor = getattr(field_value, '_tsql_type_processor', None)
+
+                # Create query builder Column directly
+                setattr(cls, field_name, Column(cls.table_name, field_name, schema=schema, type_processor=type_processor))
+                # Update annotation to reflect the Column type
+                if not hasattr(cls, '__annotations__'):
+                    cls.__annotations__ = {}
+                cls.__annotations__[field_name] = Column
+
+                # Store type processor in mapping if present
+                if type_processor is not None:
+                    cls._type_processors[field_name] = type_processor
                 continue
 
             # Check if it's a Column instance (for column_name remapping)
@@ -282,8 +343,19 @@ class Table:
                     # No column_name specified, use field_name
                     db_column_name = field_name
 
-                # Create query builder ColumnDescriptor with the DB column name
-                setattr(cls, field_name, ColumnDescriptor(db_column_name, field_type))
+                # Extract type processor if present
+                type_processor = field_value.type_processor
+
+                # Create query builder Column directly with the DB column name
+                setattr(cls, field_name, Column(cls.table_name, db_column_name, schema=schema, type_processor=type_processor))
+                # Update annotation to reflect the Column type
+                if not hasattr(cls, '__annotations__'):
+                    cls.__annotations__ = {}
+                cls.__annotations__[field_name] = Column
+
+                # Store type processor in mapping if present
+                if type_processor is not None:
+                    cls._type_processors[field_name] = type_processor
 
                 # Create SQLAlchemy column if metadata provided
                 if metadata is not None and HAS_SQLALCHEMY:
@@ -293,8 +365,12 @@ class Table:
 
             # Check if it's an Ellipsis (...) declaration
             if field_value is ...:
-                # Create query builder ColumnDescriptor
-                setattr(cls, field_name, ColumnDescriptor(field_name, None))
+                # Create query builder Column directly
+                setattr(cls, field_name, Column(cls.table_name, field_name, schema=schema))
+                # Update annotation to reflect the Column type
+                if not hasattr(cls, '__annotations__'):
+                    cls.__annotations__ = {}
+                cls.__annotations__[field_name] = Column
                 continue
 
             # Otherwise, handle type annotations
@@ -302,8 +378,12 @@ class Table:
                 # No type annotation, Ellipsis, or SA Column - skip
                 continue
 
-            # Create query builder ColumnDescriptor for type-annotated fields
-            setattr(cls, field_name, ColumnDescriptor(field_name, field_type))
+            # Create query builder Column directly for type-annotated fields
+            setattr(cls, field_name, Column(cls.table_name, field_name, schema=schema))
+            # Update annotation to reflect the Column type
+            if not hasattr(cls, '__annotations__'):
+                cls.__annotations__ = {}
+            cls.__annotations__[field_name] = Column
 
             # Create SQLAlchemy column if metadata provided
             if metadata is not None and HAS_SQLALCHEMY:
@@ -312,7 +392,20 @@ class Table:
 
         # Create SQLAlchemy Table if metadata provided
         if metadata is not None and HAS_SQLALCHEMY:
-            cls._sa_table = SATable(cls.table_name, metadata, *sa_columns, schema=schema)
+            # Extract constraints from class attribute (supports both tuple and list)
+            table_constraints = getattr(cls, 'constraints', [])
+            if isinstance(table_constraints, tuple):
+                table_constraints = list(table_constraints)
+
+            # Build keyword args for SATable
+            table_kwargs = {'schema': schema}
+            if comment is not None:
+                table_kwargs['comment'] = comment
+
+            cls._sa_table = SATable(cls.table_name, metadata, *sa_columns, *table_constraints, **table_kwargs)
+
+        # Add the ALL column for wildcard column selection
+        cls.ALL = Column(cls.table_name, '*', schema=schema)
 
     @classmethod
     def select(cls, *columns: Union['Column', Template]) -> 'SelectQueryBuilder':
@@ -364,23 +457,6 @@ class Table:
         return DeleteBuilder(cls)
 
 
-class ColumnDescriptor:
-    """Descriptor that creates Column objects when accessed on Table classes or instances"""
-
-    def __init__(self, column_name: str, python_type: type = None):
-        self.column_name = column_name
-        self.python_type = python_type
-
-    def __set_name__(self, owner, name):
-        self.column_name = name
-
-    def __get__(self, obj, objtype=None) -> Column:
-        if objtype is None:
-            objtype = type(obj)
-        schema = getattr(objtype, 'schema', None)
-        return Column(objtype.table_name, self.column_name, self.python_type, schema=schema)
-
-
 class Condition:
     """Represents a WHERE clause condition"""
 
@@ -444,7 +520,7 @@ class Condition:
 class Join:
     """Represents a JOIN clause"""
 
-    def __init__(self, table: 'Table', condition: Condition, join_type: str = 'INNER'):
+    def __init__(self, table: type['Table'], condition: Condition, join_type: str = 'INNER'):
         self.table = table
         self.condition = condition
         self.join_type = join_type
@@ -483,11 +559,62 @@ class QueryBuilder(ABC):
         """
         return self.to_tsql().render(style)
 
+    def map_results(self, rows: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
+        """Transform database rows with type processors applied.
+
+        This method applies process_result_value from type processors to convert
+        database values back to Python values (e.g., decrypt encrypted fields,
+        deserialize JSON, etc.).
+
+        Modifies row objects in place to preserve driver-specific row types
+        (e.g., asyncpg Record objects).
+
+        Args:
+            rows: List of row objects from database query results
+
+        Returns:
+            The same list of rows with transformed values (mutated in place)
+
+        Example:
+            query = User.select().where(User.id == 1)
+            rows = await conn.fetch(*query.render())
+            query.map_results(rows)  # ssn decrypted, metadata deserialized (in place)
+        """
+        if not hasattr(self, 'base_table'):
+            raise AttributeError("map_results requires a base_table attribute")
+
+        # Build a map of result_column_name -> processor
+        processors = {}
+
+        if hasattr(self, '_columns') and self._columns is not None:
+            # Explicit columns - we know exactly which ones and from which table
+            for col in self._columns:
+                if isinstance(col, Column) and col.type_processor:
+                    # The result key is the alias if present, otherwise column_name
+                    result_key = col.alias if col.alias else col.column_name
+                    processors[result_key] = col.type_processor
+        else:
+            # SELECT * - check all tables involved (base table + joins)
+            tables = [self.base_table]
+            if hasattr(self, '_joins'):
+                tables.extend(join.table for join in self._joins)
+
+            for table in tables:
+                processors.update(table._type_processors)
+
+        # Apply processors to rows in place
+        for row in rows:
+            for col_name in list(row.keys()):
+                if col_name in processors:
+                    row[col_name] = processors[col_name].process_result_value(row[col_name])
+
+        return rows
+
 
 class InsertBuilder(QueryBuilder):
     """Fluent interface for building INSERT queries"""
 
-    def __init__(self, base_table: 'Table', values: dict[str, Any]):
+    def __init__(self, base_table: type['Table'], values: dict[str, Any]):
         self.base_table = base_table
 
         # Apply defaults from SQLAlchemy columns if available
@@ -555,13 +682,23 @@ class InsertBuilder(QueryBuilder):
         self._update_cols = update
         return self
 
-    def returning(self, *columns: str) -> 'InsertBuilder':
+    def returning(self, *columns: Union[str, Column]) -> 'InsertBuilder':
         """Add RETURNING clause (Postgres/SQLite only)
 
         Args:
-            columns: Column names to return, or none for RETURNING *
+            columns: Column names (strings) or Column objects to return, or none for RETURNING *
         """
-        self._returning_cols = list(columns) if columns else ['*']
+        if columns:
+            # Convert Column objects to their column names
+            col_names = []
+            for col in columns:
+                if isinstance(col, Column):
+                    col_names.append(col.column_name)
+                else:
+                    col_names.append(col)
+            self._returning_cols = col_names
+        else:
+            self._returning_cols = ['*']
         return self
 
     def to_tsql(self) -> TSQL:
@@ -572,7 +709,15 @@ class InsertBuilder(QueryBuilder):
             table_name = f"{self.base_table.schema}.{self.base_table.table_name}"
         else:
             table_name = self.base_table.table_name
-        values_dict = self.values
+
+        # Apply type processors to values
+        values_dict = {}
+        for col_name, value in self.values.items():
+            if col_name in self.base_table._type_processors:
+                processor = self.base_table._type_processors[col_name]
+                values_dict[col_name] = processor.process_bind_param(value)
+            else:
+                values_dict[col_name] = value
 
         # MySQL INSERT IGNORE
         if self._ignore:
@@ -604,8 +749,14 @@ class InsertBuilder(QueryBuilder):
 
             # Build UPDATE SET clause
             if self._update_cols:
-                # User specified which columns to update
-                update_dict = self._update_cols
+                # User specified which columns to update - apply type processors
+                update_dict = {}
+                for col_name, value in self._update_cols.items():
+                    if col_name in self.base_table._type_processors:
+                        processor = self.base_table._type_processors[col_name]
+                        update_dict[col_name] = processor.process_bind_param(value)
+                    else:
+                        update_dict[col_name] = value
                 parts.append(t'ON CONFLICT ({conflict_cols_str:unsafe}) DO UPDATE SET {update_dict:as_set}')
             else:
                 # Default: update all non-conflict columns with EXCLUDED.*
@@ -626,7 +777,14 @@ class InsertBuilder(QueryBuilder):
         # MySQL ON DUPLICATE KEY UPDATE
         elif self._on_conflict_action == 'duplicate_key':
             if self._update_cols:
-                update_dict = self._update_cols
+                # Apply type processors
+                update_dict = {}
+                for col_name, value in self._update_cols.items():
+                    if col_name in self.base_table._type_processors:
+                        processor = self.base_table._type_processors[col_name]
+                        update_dict[col_name] = processor.process_bind_param(value)
+                    else:
+                        update_dict[col_name] = value
                 parts.append(t'ON DUPLICATE KEY UPDATE {update_dict:as_set}')
             else:
                 # Default: update all columns with alias.column (new MySQL syntax)
@@ -669,7 +827,7 @@ class InsertBuilder(QueryBuilder):
 class UpdateBuilder(QueryBuilder):
     """Fluent interface for building UPDATE queries"""
 
-    def __init__(self, base_table: 'Table', values: dict[str, Any]):
+    def __init__(self, base_table: type['Table'], values: dict[str, Any]):
         self.base_table = base_table
 
         # Apply onupdate defaults from SQLAlchemy columns if available
@@ -718,13 +876,23 @@ class UpdateBuilder(QueryBuilder):
         self._requires_where = False
         return self
 
-    def returning(self, *columns: str) -> 'UpdateBuilder':
+    def returning(self, *columns: Union[str, Column]) -> 'UpdateBuilder':
         """Add RETURNING clause (Postgres/SQLite only)
 
         Args:
-            columns: Column names to return, or none for RETURNING *
+            columns: Column names (strings) or Column objects to return, or none for RETURNING *
         """
-        self._returning_cols = list(columns) if columns else ['*']
+        if columns:
+            # Convert Column objects to their column names
+            col_names = []
+            for col in columns:
+                if isinstance(col, Column):
+                    col_names.append(col.column_name)
+                else:
+                    col_names.append(col)
+            self._returning_cols = col_names
+        else:
+            self._returning_cols = ['*']
         return self
 
     def to_tsql(self) -> TSQL:
@@ -735,7 +903,16 @@ class UpdateBuilder(QueryBuilder):
             table_name = f"{self.base_table.schema}.{self.base_table.table_name}"
         else:
             table_name = self.base_table.table_name
-        values_dict = self.values
+
+        # Apply type processors to values
+        values_dict = {}
+        for col_name, value in self.values.items():
+            if col_name in self.base_table._type_processors:
+                processor = self.base_table._type_processors[col_name]
+                values_dict[col_name] = processor.process_bind_param(value)
+            else:
+                values_dict[col_name] = value
+
         parts.append(t'UPDATE {table_name:literal} SET {values_dict:as_set}')
 
         if self._conditions:
@@ -782,7 +959,7 @@ class UpdateBuilder(QueryBuilder):
 class DeleteBuilder(QueryBuilder):
     """Fluent interface for building DELETE queries"""
 
-    def __init__(self, base_table: 'Table'):
+    def __init__(self, base_table: type['Table']):
         self.base_table = base_table
         self._conditions: List[Union[Condition, Template]] = []
         self._returning_cols: Optional[List[str]] = None
@@ -809,13 +986,23 @@ class DeleteBuilder(QueryBuilder):
         self._requires_where = False
         return self
 
-    def returning(self, *columns: str) -> 'DeleteBuilder':
+    def returning(self, *columns: Union[str, Column]) -> 'DeleteBuilder':
         """Add RETURNING clause (Postgres/SQLite only)
 
         Args:
-            columns: Column names to return, or none for RETURNING *
+            columns: Column names (strings) or Column objects to return, or none for RETURNING *
         """
-        self._returning_cols = list(columns) if columns else ['*']
+        if columns:
+            # Convert Column objects to their column names
+            col_names = []
+            for col in columns:
+                if isinstance(col, Column):
+                    col_names.append(col.column_name)
+                else:
+                    col_names.append(col)
+            self._returning_cols = col_names
+        else:
+            self._returning_cols = ['*']
         return self
 
     def to_tsql(self) -> TSQL:
@@ -872,7 +1059,7 @@ class DeleteBuilder(QueryBuilder):
 class SelectQueryBuilder(QueryBuilder):
     """Fluent interface for building SQL SELECT queries"""
 
-    def __init__(self, base_table: 'Table'):
+    def __init__(self, base_table: type['Table']):
         self.base_table = base_table
         self._columns: Optional[List[Column]] = None
         self._conditions: List[Condition] = []
@@ -910,16 +1097,16 @@ class SelectQueryBuilder(QueryBuilder):
         self._conditions.append(condition)
         return self
 
-    def join(self, table: 'Table', on: Condition, join_type: str = 'INNER') -> 'SelectQueryBuilder':
+    def join(self, table: type['Table'], on: Condition, join_type: str = 'INNER') -> 'SelectQueryBuilder':
         """Add a JOIN clause"""
         self._joins.append(Join(table, on, join_type))
         return self
 
-    def left_join(self, table: 'Table', on: Condition) -> 'SelectQueryBuilder':
+    def left_join(self, table: type['Table'], on: Condition) -> 'SelectQueryBuilder':
         """Add a LEFT JOIN clause"""
         return self.join(table, on, 'LEFT')
 
-    def right_join(self, table: 'Table', on: Condition) -> 'SelectQueryBuilder':
+    def right_join(self, table: type['Table'], on: Condition) -> 'SelectQueryBuilder':
         """Add a RIGHT JOIN clause"""
         return self.join(table, on, 'RIGHT')
 
@@ -1058,3 +1245,41 @@ if HAS_SQLALCHEMY:
         datetime: DateTime,
         float: Float,
     }
+
+
+# Helper function for type checker compatibility with SQLAlchemy columns
+def SAColumn(*args: Any, type_processor: Any = None, **kwargs: Any) -> Column:  # noqa: N802
+    """Wrapper for SQLAlchemy Column that satisfies type checkers.
+
+    This function returns a SQLAlchemy Column at runtime but tells type checkers
+    it returns a tsql Column. This allows you to use SQLAlchemy columns without
+    explicit type annotations while still getting proper IDE completions.
+
+    Usage:
+        from tsql.query_builder import Table, SAColumn
+        from sqlalchemy import Integer, String
+
+        class Users(Table):
+            id = SAColumn(Integer, primary_key=True)  # Type checker sees: tsql Column
+            name = SAColumn(String(100))
+
+        # With type processor:
+        from tsql.type_processor import TypeProcessor
+
+        class Users(Table):
+            ssn = SAColumn(String(255), type_processor=EncryptedString(key=MY_KEY))
+
+    Note: This shadows the SQLAlchemy Column import. Import SA Column explicitly if needed:
+        from sqlalchemy import Column as SA_Column
+
+    Alternative: Use explicit type annotations:
+        from sqlalchemy import Column as SACol
+        id: Column = SACol(Integer, primary_key=True)
+    """
+    if not HAS_SQLALCHEMY:
+        raise ImportError("SQLAlchemy is not installed. Cannot use SAColumn() helper.")
+    from sqlalchemy import Column as SA_Column
+    sa_col = SA_Column(*args, **kwargs)
+    if type_processor is not None:
+        sa_col._tsql_type_processor = type_processor  # type: ignore[attr-defined]
+    return sa_col  # type: ignore[return-value]
